li {
    display: inline;
}

li a {
    text-decoration: none;
    background-color: #105cc8;
    border-color: #105cc8;
    padding: 8px;
    color:#fff;
    margin: 10px;
}

li a:hover {
    background-color: #5b9ffd;
    border-color: #5b9ffd;
}

